<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>BasicEdit</name>
    <message>
        <source>Line: </source>
        <translation>Строка: </translation>
    </message>
    <message>
        <source>New Program?</source>
        <translation>Начать новую программу?</translation>
    </message>
    <message>
        <source>Are you sure you want to completely clear this program and start a new one?</source>
        <translation>Вы хотите удалить эту программу и начать новую?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Да</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Нет</translation>
    </message>
    <message>
        <source>Untitled - BASIC-256</source>
        <translation>Без названия - BASIC-256</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Сохранить файл как</translation>
    </message>
    <message>
        <source>BASIC-256 File </source>
        <translation>Файлы BASIC-256 </translation>
    </message>
    <message>
        <source>Any File </source>
        <translation>Все файлы </translation>
    </message>
    <message>
        <source> - BASIC-256</source>
        <translation> - BASIC-256</translation>
    </message>
    <message>
        <source>Open a file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>BASIC-256 file </source>
        <translation>Файлы BASIC-256 </translation>
    </message>
    <message>
        <source>The file </source>
        <translation>Файл </translation>
    </message>
    <message>
        <source> exists on file.</source>
        <translation type="obsolete"> уже существует.</translation>
    </message>
    <message>
        <source>Do you want wish to overwrite?</source>
        <translation type="obsolete">Вы хотите его перезаписать?</translation>
    </message>
    <message>
        <source>Program modifications have not been saved.</source>
        <translation>Изменения в программе не сохранены.</translation>
    </message>
    <message>
        <source>Do you want wish to discard your changes?</source>
        <translation type="obsolete">Вы действительно готовы потерять изменения?</translation>
    </message>
    <message>
        <source> Column: </source>
        <translation> Колонка: </translation>
    </message>
    <message>
        <source> already exists.</source>
        <translation> уже существует.</translation>
    </message>
    <message>
        <source>Do you want to overwrite?</source>
        <translation>Вы хотите перезаписать?</translation>
    </message>
    <message>
        <source>Do you want to discard your changes?</source>
        <translation>Вы действительно готовы потерять изменения?</translation>
    </message>
    <message>
        <source>String not found.</source>
        <translation>Строка не найдена.</translation>
    </message>
    <message>
        <source>Replace completed.</source>
        <translation>Замена выполнена.</translation>
    </message>
</context>
<context>
    <name>DocumentationWin</name>
    <message>
        <source>Help Navigation</source>
        <translation type="obsolete">Навигация по справке</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="obsolete">Поиск:</translation>
    </message>
    <message>
        <source>Search Forward</source>
        <translation type="obsolete">Поиск вперед</translation>
    </message>
    <message>
        <source>Search Backward</source>
        <translation type="obsolete">Поиск назад</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперед</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Домой</translation>
    </message>
    <message>
        <source>&amp;Exit</source>
        <translation>В&amp;ыход</translation>
    </message>
</context>
<context>
    <name>FindWin</name>
    <message>
        <source>BASIC-256 Find</source>
        <translation>BASIC-256 Найти</translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Учитывать регистр</translation>
    </message>
    <message>
        <source>Search Backwards</source>
        <translation>Искать назад</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
</context>
<context>
    <name>Interpreter</name>
    <message>
        <source>ERROR on line </source>
        <translation>ОШИБКА в строке </translation>
    </message>
    <message>
        <source>Syntax error on line </source>
        <translation>Ошибка синтаксиса на строке </translation>
    </message>
    <message>
        <source> around end of line.</source>
        <translation> в конце строки.</translation>
    </message>
    <message>
        <source> around column </source>
        <translation> в колонке </translation>
    </message>
    <message>
        <source>No such label</source>
        <translation type="obsolete">Нет такой метки</translation>
    </message>
    <message>
        <source>Next without FOR</source>
        <translation type="obsolete">Next без FOR</translation>
    </message>
    <message>
        <source>Array dimension too large</source>
        <translation type="obsolete">Слишком много элементов в массиве</translation>
    </message>
    <message>
        <source>Cannot assign non-string to string array</source>
        <translation type="obsolete">Нельзя назначить не-строчное значение массиву строк</translation>
    </message>
    <message>
        <source>Array index out of bounds</source>
        <translation type="obsolete">Выход за границы массива</translation>
    </message>
    <message>
        <source>Cannot access non-array variable</source>
        <translation type="obsolete">Нельзя получить доступ к переменной, не являющейся массивом</translation>
    </message>
    <message>
        <source>Unknown variable</source>
        <translation type="obsolete">Неизвестная переменная</translation>
    </message>
    <message>
        <source>Illegal argument to int()</source>
        <translation type="obsolete">Незаконный аргумент для int()</translation>
    </message>
    <message>
        <source>Illegal argument to string()</source>
        <translation type="obsolete">Незаконный аргумент для string()</translation>
    </message>
    <message>
        <source>Illegal argument to sin()</source>
        <translation type="obsolete">Незаконный аргумент для sin()</translation>
    </message>
    <message>
        <source>Illegal argument to cos()</source>
        <translation type="obsolete">Незаконный аргумент для cos()</translation>
    </message>
    <message>
        <source>Illegal argument to tan()</source>
        <translation type="obsolete">Незаконный аргумент для tan()</translation>
    </message>
    <message>
        <source>Illegal argument to ceil()</source>
        <translation type="obsolete">Незаконный аргумент для ceil()</translation>
    </message>
    <message>
        <source>Illegal argument to floor()</source>
        <translation type="obsolete">Незаконный аргумент для floor()</translation>
    </message>
    <message>
        <source>Illegal argument to abs()</source>
        <translation type="obsolete">Незаконный аргумент для abs()</translation>
    </message>
    <message>
        <source>String in numeric expression</source>
        <translation type="obsolete">Строка в численном выражении</translation>
    </message>
    <message>
        <source>Cannot compare strings with &gt; or &lt;=</source>
        <translation type="obsolete">Нельзя сравнивать строки с помощью &gt; или &lt;=</translation>
    </message>
    <message>
        <source>Cannot compare strings with &lt; or &gt;=</source>
        <translation type="obsolete">Нельзя сравнивать строки с помощью &lt; или &gt;=</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation type="obsolete">Невозможно открыть файл</translation>
    </message>
    <message>
        <source>Illegal argument to open()</source>
        <translation type="obsolete">Незаконный аргумент для open()</translation>
    </message>
    <message>
        <source>Can&apos;t read -- no open file.</source>
        <translation type="obsolete">Не удалось чтение - нет открытого файла.</translation>
    </message>
    <message>
        <source>Unable to write to file</source>
        <translation type="obsolete">Невозможно записать в файл</translation>
    </message>
    <message>
        <source>Illegal argument to write()</source>
        <translation type="obsolete">Незаконный аргумент для write()</translation>
    </message>
    <message>
        <source>Illegal argument to length()</source>
        <translation type="obsolete">Незаконный аргумент для length()</translation>
    </message>
    <message>
        <source>Illegal argument to poly()</source>
        <translation type="obsolete">Незаконный аргумент для poly()</translation>
    </message>
    <message>
        <source>Not enough points in array for poly()</source>
        <translation type="obsolete">Не хватает точек в массиве для poly()</translation>
    </message>
    <message>
        <source>reset() called when no file is open</source>
        <translation type="obsolete">Вызов reset() без открытых файлов</translation>
    </message>
    <message>
        <source>Unable to reset file</source>
        <translation type="obsolete">Не удается очистить файл</translation>
    </message>
    <message>
        <source>Illegal argument to mid()</source>
        <translation type="obsolete">Незаконный аргумент для mid()</translation>
    </message>
    <message>
        <source>String not long enough for given starting character</source>
        <translation type="obsolete">Недостаточная длина строки для заданного начального символа</translation>
    </message>
    <message>
        <source>Illegal argument to instr()</source>
        <translation type="obsolete">Незаконный аргумент для instr()</translation>
    </message>
    <message>
        <source>Illegal FOR -- start number &gt; end number</source>
        <translation type="obsolete">Неверный FOR -- начальный индекс &gt; конечного</translation>
    </message>
    <message>
        <source>Illegal FOR -- start number &lt; end number</source>
        <translation type="obsolete">Неверный FOR -- начальный индекс &lt; конечного</translation>
    </message>
    <message>
        <source>Array dimension too small</source>
        <translation type="obsolete">Размер массива слишком мал</translation>
    </message>
    <message>
        <source>Can&apos;t size -- no open file.</source>
        <translation type="obsolete">Размер неизвестен -- нет открытого файла.</translation>
    </message>
    <message>
        <source>seek() called when no file is open</source>
        <translation type="obsolete">ssek() вызывается, когда файл не открыт</translation>
    </message>
    <message>
        <source>Not a string array variable</source>
        <translation type="obsolete">Нет переменной массива строк</translation>
    </message>
    <message>
        <source>Not an array variable</source>
        <translation type="obsolete">Нет переменной массива</translation>
    </message>
    <message>
        <source>Argument not an array for poly()</source>
        <translation type="obsolete">Аргумент для poly() не массив</translation>
    </message>
    <message>
        <source>Not enough points in immediate list for poly()</source>
        <translation type="obsolete">Недостаточно точек с списке для poly()</translation>
    </message>
    <message>
        <source>Not enough points in array for stamp()</source>
        <translation type="obsolete">Недостаточно точек в массиве для stamp()</translation>
    </message>
    <message>
        <source>Argument not an array for stamp()</source>
        <translation type="obsolete">Аргумент для stamp() не массив</translation>
    </message>
    <message>
        <source>Not enough points in immediate list for stamp()</source>
        <translation type="obsolete">Недостаточно точек в списке для stamp()</translation>
    </message>
    <message>
        <source>Illegal argument</source>
        <translation type="obsolete">Неверный аргумент</translation>
    </message>
    <message>
        <source>RGB Color values must be in the range of 0 to 255.</source>
        <translation type="obsolete">Значения RGB цветов должны быть в диапазоне от 0 до 255.</translation>
    </message>
    <message>
        <source>String input to putbit incorrect.</source>
        <translation type="obsolete">Строка ввода в putbit некорректна.</translation>
    </message>
    <message>
        <source>Unable to load image file.</source>
        <translation type="obsolete">Невозможно загрузить графический файл.</translation>
    </message>
    <message>
        <source>Sprite number out of range.</source>
        <translation type="obsolete">Номер спрайта вне диапазона.</translation>
    </message>
    <message>
        <source>Sprite has not been assigned.</source>
        <translation type="obsolete">Спрайт не был назначен.</translation>
    </message>
    <message>
        <source>Invallid File Number</source>
        <translation type="obsolete">Неверный номер файла</translation>
    </message>
    <message>
        <source>Unable to slice image.</source>
        <translation type="obsolete">Невозможно отрезать изображение.</translation>
    </message>
    <message>
        <source>Invalid Extended Op-code.</source>
        <translation type="obsolete">Неверный расширенный Op-код.</translation>
    </message>
    <message>
        <source>Invalid directory name.</source>
        <translation type="obsolete">Неверное имя каталога.</translation>
    </message>
    <message>
        <source>ERROR - Unable to initialize Winsock library.
</source>
        <translation>ОШИБКА - невозможно инциализировать Winsock.</translation>
    </message>
    <message>
        <source>ERROR - Unable to find inpout32.dll - direct port I/O disabled.
</source>
        <translation>ОШИБКА - не найден inpout32.dll - .порт ввода-вывода отключен.</translation>
    </message>
    <message>
        <source>ERROR - Unable to find Inp32 in inpout32.dll - direct port I/O disabled.
</source>
        <translation>ОШИБКА - не найден Inp32 в inpout32.dll - .порт ввода-вывода отключен.</translation>
    </message>
    <message>
        <source>ERROR - Unable to find Out32 in inpout32.dll - direct port I/O disabled.
</source>
        <translation>ОШИБКА - не найден Out32 в inpout32.dll - .порт ввода-вывода отключен.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Program modifications have not been saved.</source>
        <translation>Изменения в программе не сохранены.</translation>
    </message>
    <message>
        <source>Do you want wish to discard your changes?</source>
        <translation type="obsolete">Вы действительно готовы потерять изменения?</translation>
    </message>
    <message>
        <source>Do you want to discard your changes?</source>
        <translation>Вы готовы потерять изменения?</translation>
    </message>
</context>
<context>
    <name>PreferencesWin</name>
    <message>
        <source>BASIC-256 Preferences and Settings</source>
        <translation>BASIC-256 настройки и параметры</translation>
    </message>
    <message>
        <source>Preferences and Settings Password:</source>
        <translation>Пароль для настроек:</translation>
    </message>
    <message>
        <source>Allow SYSTEM statement</source>
        <translation>Разрешить SYSTEM</translation>
    </message>
    <message>
        <source>Allow GETSETTING/SETSETTING statements</source>
        <translation>Разрешить GETSETTING/SETSETTING</translation>
    </message>
    <message>
        <source>Allow PORTIN/PORTOUT statements</source>
        <translation>Разрешить PORTIN/PORTOUT</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Preferences and settings have been saved.</source>
        <translation>Настройки и параметры сохранены.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Run</source>
        <translation type="obsolete">Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Стоп</translation>
    </message>
    <message>
        <source>Step</source>
        <translation type="obsolete">Шаг</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="obsolete">Файл</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="obsolete">Новая программа</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="obsolete">Открыть</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Сохранить</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="obsolete">Сохранить как</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Выход</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="obsolete">Правка</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="obsolete">Вырезать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="obsolete">Выбрать все</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="obsolete">Отладка</translation>
    </message>
    <message>
        <source>Save Compiled Byte Code</source>
        <translation type="obsolete">Сохранить байт-код</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>About BASIC-256</source>
        <translation>О BASIC-256</translation>
    </message>
    <message>
        <source>Graphics Output</source>
        <translation>Окно вывода графики</translation>
    </message>
    <message>
        <source>Text Output</source>
        <translation>Окно ввода-вывода текста</translation>
    </message>
    <message>
        <source>Ready.</source>
        <translation>Готово.</translation>
    </message>
    <message>
        <source>Untitled - BASIC-256</source>
        <translation>Без названия - BASIC-256</translation>
    </message>
    <message>
        <source>Print Code</source>
        <translation>Распечатать исходный текст</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печать</translation>
    </message>
    <message>
        <source>Print Text Output</source>
        <translation>Распечатать текстовый вывод</translation>
    </message>
    <message>
        <source>Print Graphics Output</source>
        <translation>Распечатать графический вывод</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="obsolete">Просмотр</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation type="obsolete">Панели инструментов</translation>
    </message>
    <message>
        <source>Main</source>
        <translation type="obsolete">Главный</translation>
    </message>
    <message>
        <source>Print Error</source>
        <translation>Ошибка печати</translation>
    </message>
    <message>
        <source>Unable to carry out printing.
Please check your printer settings.</source>
        <translation>Не удается распечатать информацию.
Проверьте настройки принтера.</translation>
    </message>
    <message>
        <source>Text Window</source>
        <translation type="obsolete">Окно текста</translation>
    </message>
    <message>
        <source>Graphics Window</source>
        <translation type="obsolete">Окно графики</translation>
    </message>
    <message>
        <source>Variable Watch Window</source>
        <translation type="obsolete">Окно просмотра переменных</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Открыть...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Сохранить &amp;как...</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>П&amp;ечать...</translation>
    </message>
    <message>
        <source>&amp;Exit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Вы&amp;резать</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Вы&amp;делить все</translation>
    </message>
    <message>
        <source>&amp;Beautify</source>
        <translation>Красивый к&amp;од</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>&amp;Text Window</source>
        <translation>&amp;Окно ввода-вывода текста</translation>
    </message>
    <message>
        <source>&amp;Graphics Window</source>
        <translation>Окно вывода &amp;графики</translation>
    </message>
    <message>
        <source>&amp;Variable Watch Window</source>
        <translation>&amp;Наблюдение за переменными</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>&amp;Панели инструментов</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Главная</translation>
    </message>
    <message>
        <source>&amp;Text Output</source>
        <translation>&amp;Ввод-вывод текста</translation>
    </message>
    <message>
        <source>&amp;Graphics Output</source>
        <translation>Вывод &amp;графики</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>С&amp;тарт</translation>
    </message>
    <message>
        <source>&amp;Debug</source>
        <translation>&amp;Отладка</translation>
    </message>
    <message>
        <source>S&amp;tep</source>
        <translation>&amp;Шаг</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Ст&amp;оп</translation>
    </message>
    <message>
        <source>Save Compiled &amp;Byte Code</source>
        <translation type="obsolete">Сохранить &amp;байт-код</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>&amp;About BASIC-256</source>
        <translation>&amp;О BASIC-256</translation>
    </message>
    <message>
        <source>&amp;Font Size</source>
        <translation>Размер &amp;шрифта</translation>
    </message>
    <message>
        <source>&amp;Small</source>
        <translation>&amp;Мелкий</translation>
    </message>
    <message>
        <source>&amp;Medium</source>
        <translation>&amp;Средний</translation>
    </message>
    <message>
        <source>&amp;Large</source>
        <translation>&amp;Большой</translation>
    </message>
    <message>
        <source>&amp;Huge</source>
        <translation>&amp;Огромный</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>О&amp;тмена</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Повтор</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>BASIC-256 Reference</source>
        <translation>Справочник по BASIC-256</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Интернет-справка</translation>
    </message>
    <message>
        <source>&lt;h2&gt;BASIC-256&lt;/h2&gt;version &lt;b&gt;</source>
        <translation>&lt;h2&gt;BASIC-256&lt;/h2&gt;версия &lt;b&gt;</translation>
    </message>
    <message>
        <source>&lt;/b&gt;&lt;p&gt;Copyright &amp;copy; 2006-2010, The BASIC-256 Team&lt;/p&gt;&lt;p&gt;Please visit our web site at &lt;a href=http://www.basic256.org&gt;basic256.org&lt;/a&gt; for tutorials and documentation.&lt;/p&gt;&lt;p&gt;Please see the CONTRIBUTORS file for a list of developers and translators for this project.&lt;/p&gt;&lt;p&gt;&lt;i&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;/b&gt;&lt;p&gt;Авторское право &amp;copy; 2006-2010, Команда BASIC-256&lt;/p&gt;&lt;p&gt;На веб-сайте &lt;a href=http://www.basic256.org&gt;basic256.org&lt;/a&gt; вы найдете руководства и документацию.&lt;/p&gt;&lt;p&gt;В файле CONTRIBUTORS - имена и контакты разработчиков и переводчиков проекта.&lt;/p&gt;&lt;p&gt;&lt;i&gt;Вы должны получить копию GNU General Public License вместе с этой программой, а если нет, напишите в Free Software Foundation, Inc, 51-Франклин-стрит, 5й этаж, Boston, MA 02110-1301 USA.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Найти</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Заменить</translation>
    </message>
    <message>
        <source>&amp;Edit Window</source>
        <translation>&amp;Окно редактора</translation>
    </message>
</context>
<context>
    <name>ReplaceWin</name>
    <message>
        <source>BASIC-256 Replace</source>
        <translation>BASIC-256 Заменить</translation>
    </message>
    <message>
        <source>From:</source>
        <translation>Заменить:</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>На:</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Учитывать регистр</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Заменить всё</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
</context>
<context>
    <name>RunController</name>
    <message>
        <source>Running</source>
        <translation>Работает</translation>
    </message>
    <message>
        <source>Ready.</source>
        <translation>Готово.</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Приостановлено</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Сохранить файл как</translation>
    </message>
    <message>
        <source>BASIC-256 Compiled File </source>
        <translation>Компилированный файл BASIC-256 </translation>
    </message>
    <message>
        <source>Any File </source>
        <translation>Все файлы </translation>
    </message>
    <message>
        <source>BASIC-256 Preferences and Settings</source>
        <translation>BASIC-256 настройки и параметры</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
<context>
    <name>VariableWin</name>
    <message>
        <source>Variable Watch</source>
        <translation>Наблюдение за переменными</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя переменной</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <source>&lt;array </source>
        <translation>&lt;массив </translation>
    </message>
</context>
</TS>
